@@ -301,7 +301,7 @@ def _create_train_task(name: str,
 
 def upload(
     algorithm_cloud_name: str,
-    algorithm_entrypoint: str,
+    algorithm_entrypoint: str=None,
     algorithm_output: Optional[str]=None,
     algorithm_local_dir: Optional[Union[str, Path]]='.',
     algorithm_force_update: bool=False,
@@ -339,7 +339,14 @@ def run(
     try:
         algo = AlgorithmArtifact.from_full_name(algorithm_cloud_name)
     except HTTPError as e:
-        cmd_error(f"Algorithm {algorithm_cloud_name} not found.")
+        status_code = e.response.status_code
+        if status_code == 404:
+            cmd_error(f"Algorithm {algorithm_cloud_name} not found.")
+        else:
+            cmd_error(
+                f"Error fetching algorithm {algorithm_cloud_name}, "
+                "status code {status_code}."
+            )
         return None
     kw['algorithm_id'] = algo.id
 
@@ -348,9 +355,15 @@ def run(
         try:
             project = SDKProject.from_full_name(kw.pop('project_name'))
         except HTTPError as e:
-            if e.response.status_code == 404:
+            status_code = e.response.status_code
+            if status_code == 404:
                 cmd_error(f"Project {project_name} not found.")
-                return None
+            else:
+                cmd_error(
+                    f"Error fetching project {project_name}, "
+                    "status code {status_code}."
+                )
+            return None
         kw['project_id'] = project.id
 
     t, _, _, _ = quick_train(**kw)
@@ -377,9 +390,15 @@ def upload_and_run(
         try:
             project = SDKProject.from_full_name(kw.pop('project_name'))
         except HTTPError as e:
-            if e.response.status_code == 404:
+            status_code = e.response.status_code
+            if status_code == 404:
                 cmd_error(f"Project {project_name} not found.")
-                return None
+            else:
+                cmd_error(
+                    f"Error fetching project {project_name}, "
+                    "status code {status_code}."
+                )
+            return None
         kw['project_id'] = project.id
 
     t, _, _, _ = quick_train(**kw)
@@ -797,7 +816,7 @@ def quick_train(algorithm_id: Optional[str]=None,
     # Algorithm
     _algo_name = algorithm_name or algorithm_cloud_name
     _algo_dir = algorithm_dir or algorithm_local_dir
-    _image_name = mirror_name or image_name
+    _image_name = mirror_name if image_name == 'QUICKSTART' else image_name
     try:
         algo, current_sha = sync_algorithm(
             id=algorithm_id,
